==> centreon-web-22.10.29.tar.gz: centreon-web-22.10.29/src/Centreon/Tests/Application/DataRepresenter/ValidatorErrorListTest.php <==
<?php
/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Tests\Application\DataRepresenter;

use PHPUnit\Framework\TestCase;
use Symfony\Component\Validator;
use Centreon\Application\DataRepresenter\ValidatorErrorList;

class ValidatorErrorListTest extends TestCase
{
    public function testJsonSerialize()
    {
        $field = 'input-field';
        $msg1 = 'error N1';
        $msg2 = 'error N2';

        // list of violations
        $errors = [
            new Validator\ConstraintViolation($msg1, null, [], null, $field, null, null, null, null),
            new Validator\ConstraintViolation($msg2, null, [], null, $field, null, null, null, null),
        ];

        // excpected result
        $expected = [
            [
                'field' => $field,
                'messages' => $msg1,
            ],
            [
                'field' => $field,
                'messages' => $msg2,
            ],
        ];

        // load data representer
        $dataRepresenter = new ValidatorErrorList(new Validator\ConstraintViolationList($errors));

        $this->assertEquals($expected, $dataRepresenter->jsonSerialize());
    }
}

==> centreon-web-24.04.21.tar.gz: centreon-web-24.04.21/src/Centreon/Tests/Application/DataRepresenter/ValidatorErrorListTest.php <==
<?php
/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Tests\Application\DataRepresenter;

use PHPUnit\Framework\TestCase;
use Symfony\Component\Validator;
use Centreon\Application\DataRepresenter\ValidatorErrorList;

class ValidatorErrorListTest extends TestCase
{
    public function testJsonSerialize(): void
    {
        $field = 'input-field';
        $msg1 = 'error N1';
        $msg2 = 'error N2';

        // list of violations
        $errors = [
            new Validator\ConstraintViolation($msg1, null, [], null, $field, null, null, null, null),
            new Validator\ConstraintViolation($msg2, null, [], null, $field, null, null, null, null),
        ];

        // excpected result
        $expected = [
            [
                'field' => $field,
                'messages' => $msg1,
            ],
            [
                'field' => $field,
                'messages' => $msg2,
            ],
        ];

        // load data representer
        $dataRepresenter = new ValidatorErrorList(new Validator\ConstraintViolationList($errors));

        $this->assertEquals($expected, $dataRepresenter->jsonSerialize());
    }
}
